@@ -3,7 +3,7 @@ from bolinette.blnt.model import Model, ModelMetadata, ModelProperty
 from bolinette.blnt.mixin import Mixin
 from bolinette.blnt.repository import Repository
 from bolinette.blnt.service import Service, ServiceMetadata, SimpleService, HistorizedService
-from bolinette.blnt.controller import (Controller, SimpleController, ControllerMetadata, ControllerRoute,
+from bolinette.blnt.controller import (Controller, ControllerMetadata, ControllerRoute,
                                        ControllerExcepts, ControllerReturns)
 from bolinette.blnt.topic import Topic, TopicMetadata, TopicChannel
 from bolinette.blnt.static import StaticController
